@@ -1,5 +1,5 @@
-#ifndef GNUMERIC_SHEET_H
-#define GNUMERIC_SHEET_H
+#ifndef GNUMERIC_GNUMERIC_SHEET_H
+#define GNUMERIC_GNUMERIC_SHEET_H
 
 #include "item-grid.h"
 #include "item-cursor.h"
@@ -36,7 +36,8 @@ typedef struct {
 
 	SheetModeType mode;
 	
-	/* This flag keeps track of a cell selector
+	/*
+	 * This flag keeps track of a cell selector
 	 * (ie, when the user uses the cursor keys
 	 * to select a cell for an expression).
 	 */
@@ -44,6 +45,10 @@ typedef struct {
 	int           sel_cursor_pos;
 	int           sel_text_len;
 	ItemCursor    *selection;
+
+	/*
+	 * The column and row bars
+	 */
 	ItemBar       *colbar;
 	ItemBar       *rowbar;
 
@@ -54,14 +59,16 @@ GtkType    gnumeric_sheet_get_type               (void);
 
 GtkWidget *gnumeric_sheet_new            	 (SheetView *sheet, ItemBar *colbar, ItemBar *rowbar);
 void       gnumeric_sheet_set_selection  	 (GnumericSheet *gsheet, SheetSelection *ss);
+void       gnumeric_sheet_set_top_row            (GnumericSheet *gsheet, int new_top_row);
+void       gnumeric_sheet_set_top_col            (GnumericSheet *gsheet, int new_top_col);
 void       gnumeric_sheet_cursor_set     	 (GnumericSheet *gsheet,
 					 	  int col, int row);
 void       gnumeric_sheet_move_cursor            (GnumericSheet *gsheet,
 						  int col, int row);
+int        gnumeric_sheet_can_move_cursor        (GnumericSheet *gsheet);
 void       gnumeric_sheet_set_cursor_bounds      (GnumericSheet *gsheet,
 						  int start_col, int start_row,
 						  int end_col,   int end_row);
-void       gnumeric_sheet_stop_editing           (GnumericSheet *sheet);
 void       gnumeric_sheet_compute_visible_ranges (GnumericSheet *gsheet);
 void       gnumeric_sheet_make_cell_visible      (GnumericSheet *gsheet,
 						  int col, int row);
@@ -72,9 +79,20 @@ void       gnumeric_sheet_stop_cell_selection    (GnumericSheet *gsheet);
 void       gnumeric_sheet_create_editing_cursor  (GnumericSheet *gsheet);
 void       gnumeric_sheet_destroy_editing_cursor (GnumericSheet *gsheet);
 
+/* Managing the selection of cell ranges when editing a formula */
+
+void       gnumeric_sheet_start_cell_selection   (GnumericSheet *gsheet,
+						  int col, int row);
+void       gnumeric_sheet_stop_cell_selection    (GnumericSheet *gsheet);
+void       gnumeric_sheet_selection_cursor_place (GnumericSheet *gsheet,
+						  int col, int row);
+void       gnumeric_sheet_selection_extend       (GnumericSheet *gsheet,
+						  int col, int row);
+void       gnumeric_sheet_stop_editing           (GnumericSheet *sheet);
+
 typedef struct {
 	GnomeCanvasClass parent_class;
 } GnumericSheetClass;
-#endif
+#endif /* GNUMERIC_GNUMERIC_SHEET_H */
 
 
